==> ejc-proother-api-3.0.0-20220720.094315-149-sources.jar: com/ejianc/business/proother/contract/vo/ContractOtherCostVO.java <==
package com.ejianc.business.proother.contract.vo;


import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

/**
 * 分包合同其他费用
 * 
 * @author generator
 * 
 */
public class ContractOtherCostVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    /**
     * 序号
     */
    private String treeIndex;

    /**
     * 费用名称
     */
    private String costName;

    /**
     * 数量
     */
    private BigDecimal costNum;

    /**
     * 单价（无税）
     */
    private BigDecimal costPrice;

    /**
     * 税率
     */
    private BigDecimal costTaxRate;

    /**
     * 单价（含税）
     */
    private BigDecimal costTaxPrice;

    /**
     * 金额无税
     */
    private BigDecimal costMny;

    /**
     * 金额（含税）
     */
    private BigDecimal costTaxMny;

    /**
     * 税金
     */
    private BigDecimal costTax;

    /**
     * 备注
     */
    private String costMemo;

    /**
     * 变更主键
     */
    private Long changeId;

    /**
     * 变更子表主键
     */
    private Long changeBid;

    /**
     * 所属合同Id
     */
    private Long contractId;

    /**
     * 变更类型
     */
    private String changeType;


    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }

    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }

    public BigDecimal getCostNum() {
        return costNum;
    }

    public void setCostNum(BigDecimal costNum) {
        this.costNum = costNum;
    }

    public BigDecimal getCostPrice() {
        return costPrice;
    }

    public void setCostPrice(BigDecimal costPrice) {
        this.costPrice = costPrice;
    }

    public BigDecimal getCostTaxRate() {
        return costTaxRate;
    }

    public void setCostTaxRate(BigDecimal costTaxRate) {
        this.costTaxRate = costTaxRate;
    }

    public BigDecimal getCostTaxPrice() {
        return costTaxPrice;
    }

    public void setCostTaxPrice(BigDecimal costTaxPrice) {
        this.costTaxPrice = costTaxPrice;
    }

    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }

    public BigDecimal getCostTaxMny() {
        return costTaxMny;
    }

    public void setCostTaxMny(BigDecimal costTaxMny) {
        this.costTaxMny = costTaxMny;
    }

    public BigDecimal getCostTax() {
        return costTax;
    }

    public void setCostTax(BigDecimal costTax) {
        this.costTax = costTax;
    }

    public String getCostMemo() {
        return costMemo;
    }

    public void setCostMemo(String costMemo) {
        this.costMemo = costMemo;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
}

==> ejc-proother-api-3.0.0-20230411.130133-198-sources.jar: com/ejianc/business/proother/contract/vo/ContractOtherCostVO.java <==
package com.ejianc.business.proother.contract.vo;


import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

/**
 * 分包合同其他费用
 * 
 * @author generator
 * 
 */
public class ContractOtherCostVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    /**
     * 序号
     */
    private String treeIndex;

    /**
     * 费用名称
     */
    private String costName;

    /**
     * 数量
     */
    private BigDecimal costNum;

    /**
     * 单价（无税）
     */
    private BigDecimal costPrice;

    /**
     * 税率
     */
    private BigDecimal costTaxRate;

    /**
     * 单价（含税）
     */
    private BigDecimal costTaxPrice;

    /**
     * 金额无税
     */
    private BigDecimal costMny;

    /**
     * 金额（含税）
     */
    private BigDecimal costTaxMny;

    /**
     * 税金
     */
    private BigDecimal costTax;

    /**
     * 备注
     */
    private String costMemo;

    /**
     * 变更主键
     */
    private Long changeId;

    /**
     * 变更子表主键
     */
    private Long changeBid;

    /**
     * 所属合同Id
     */
    private Long contractId;

    /**
     * 变更类型
     */
    private String changeType;

    private String costPriceStr;
    private String costTaxPriceStr;
    private String costMnyStr;
    private String costTaxMnyStr;
    private String costTaxStr;
    private String costNumStr;
    private String costTaxRateStr;

    public String getCostNumStr() {
        return costNumStr;
    }

    public void setCostNumStr(String costNumStr) {
        this.costNumStr = costNumStr;
    }

    public String getCostTaxRateStr() {
        return costTaxRateStr;
    }

    public void setCostTaxRateStr(String costTaxRateStr) {
        this.costTaxRateStr = costTaxRateStr;
    }

    public String getCostPriceStr() {
        return costPriceStr;
    }

    public void setCostPriceStr(String costPriceStr) {
        this.costPriceStr = costPriceStr;
    }

    public String getCostTaxPriceStr() {
        return costTaxPriceStr;
    }

    public void setCostTaxPriceStr(String costTaxPriceStr) {
        this.costTaxPriceStr = costTaxPriceStr;
    }

    public String getCostMnyStr() {
        return costMnyStr;
    }

    public void setCostMnyStr(String costMnyStr) {
        this.costMnyStr = costMnyStr;
    }

    public String getCostTaxMnyStr() {
        return costTaxMnyStr;
    }

    public void setCostTaxMnyStr(String costTaxMnyStr) {
        this.costTaxMnyStr = costTaxMnyStr;
    }

    public String getCostTaxStr() {
        return costTaxStr;
    }

    public void setCostTaxStr(String costTaxStr) {
        this.costTaxStr = costTaxStr;
    }

    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }

    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }

    public BigDecimal getCostNum() {
        return costNum;
    }

    public void setCostNum(BigDecimal costNum) {
        this.costNum = costNum;
    }

    public BigDecimal getCostPrice() {
        return costPrice;
    }

    public void setCostPrice(BigDecimal costPrice) {
        this.costPrice = costPrice;
    }

    public BigDecimal getCostTaxRate() {
        return costTaxRate;
    }

    public void setCostTaxRate(BigDecimal costTaxRate) {
        this.costTaxRate = costTaxRate;
    }

    public BigDecimal getCostTaxPrice() {
        return costTaxPrice;
    }

    public void setCostTaxPrice(BigDecimal costTaxPrice) {
        this.costTaxPrice = costTaxPrice;
    }

    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }

    public BigDecimal getCostTaxMny() {
        return costTaxMny;
    }

    public void setCostTaxMny(BigDecimal costTaxMny) {
        this.costTaxMny = costTaxMny;
    }

    public BigDecimal getCostTax() {
        return costTax;
    }

    public void setCostTax(BigDecimal costTax) {
        this.costTax = costTax;
    }

    public String getCostMemo() {
        return costMemo;
    }

    public void setCostMemo(String costMemo) {
        this.costMemo = costMemo;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
}
